==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/scheduler/kotlin/inputs/ServiceBusTopicMessageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scheduler.kotlin.inputs

import com.pulumi.azurenative.scheduler.inputs.ServiceBusTopicMessageArgs.builder
import com.pulumi.azurenative.scheduler.kotlin.enums.ServiceBusTransportType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property authentication Gets or sets the Service Bus authentication.
 * @property brokeredMessageProperties Gets or sets the brokered message properties.
 * @property customMessageProperties Gets or sets the custom message properties.
 * @property message Gets or sets the message.
 * @property namespace Gets or sets the namespace.
 * @property topicPath Gets or sets the topic path.
 * @property transportType Gets or sets the transport type.
 */
public data class ServiceBusTopicMessageArgs(
    public val authentication: Output<ServiceBusAuthenticationArgs>? = null,
    public val brokeredMessageProperties: Output<ServiceBusBrokeredMessagePropertiesArgs>? = null,
    public val customMessageProperties: Output<Map<String, String>>? = null,
    public val message: Output<String>? = null,
    public val namespace: Output<String>? = null,
    public val topicPath: Output<String>? = null,
    public val transportType: Output<ServiceBusTransportType>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scheduler.inputs.ServiceBusTopicMessageArgs> {
    override fun toJava(): com.pulumi.azurenative.scheduler.inputs.ServiceBusTopicMessageArgs =
        com.pulumi.azurenative.scheduler.inputs.ServiceBusTopicMessageArgs.builder()
            .authentication(authentication?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .brokeredMessageProperties(
                brokeredMessageProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .customMessageProperties(
                customMessageProperties?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .message(message?.applyValue({ args0 -> args0 }))
            .namespace(namespace?.applyValue({ args0 -> args0 }))
            .topicPath(topicPath?.applyValue({ args0 -> args0 }))
            .transportType(transportType?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ServiceBusTopicMessageArgs].
 */
@PulumiTagMarker
public class ServiceBusTopicMessageArgsBuilder internal constructor() {
    private var authentication: Output<ServiceBusAuthenticationArgs>? = null

    private var brokeredMessageProperties: Output<ServiceBusBrokeredMessagePropertiesArgs>? = null

    private var customMessageProperties: Output<Map<String, String>>? = null

    private var message: Output<String>? = null

    private var namespace: Output<String>? = null

    private var topicPath: Output<String>? = null

    private var transportType: Output<ServiceBusTransportType>? = null

    /**
     * @param value Gets or sets the Service Bus authentication.
     */
    @JvmName("dicfbsiqlennusnx")
    public suspend fun authentication(`value`: Output<ServiceBusAuthenticationArgs>) {
        this.authentication = value
    }

    /**
     * @param value Gets or sets the brokered message properties.
     */
    @JvmName("euonbyjfvxkcpccp")
    public suspend
    fun brokeredMessageProperties(`value`: Output<ServiceBusBrokeredMessagePropertiesArgs>) {
        this.brokeredMessageProperties = value
    }

    /**
     * @param value Gets or sets the custom message properties.
     */
    @JvmName("fduxpepenjjlsdyp")
    public suspend fun customMessageProperties(`value`: Output<Map<String, String>>) {
        this.customMessageProperties = value
    }

    /**
     * @param value Gets or sets the message.
     */
    @JvmName("fucjckeebisvhvab")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value Gets or sets the namespace.
     */
    @JvmName("qgostqbyiqqjjnto")
    public suspend fun namespace(`value`: Output<String>) {
        this.namespace = value
    }

    /**
     * @param value Gets or sets the topic path.
     */
    @JvmName("fojifmklhbiubdma")
    public suspend fun topicPath(`value`: Output<String>) {
        this.topicPath = value
    }

    /**
     * @param value Gets or sets the transport type.
     */
    @JvmName("rcrluiwunnvnrfau")
    public suspend fun transportType(`value`: Output<ServiceBusTransportType>) {
        this.transportType = value
    }

    /**
     * @param value Gets or sets the Service Bus authentication.
     */
    @JvmName("fhsucletfftiybqu")
    public suspend fun authentication(`value`: ServiceBusAuthenticationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param argument Gets or sets the Service Bus authentication.
     */
    @JvmName("mtqoapeewdhsmgxd")
    public suspend
    fun authentication(argument: suspend ServiceBusAuthenticationArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusAuthenticationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.authentication = mapped
    }

    /**
     * @param value Gets or sets the brokered message properties.
     */
    @JvmName("omkggmewvluvfjjc")
    public suspend fun brokeredMessageProperties(`value`: ServiceBusBrokeredMessagePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.brokeredMessageProperties = mapped
    }

    /**
     * @param argument Gets or sets the brokered message properties.
     */
    @JvmName("hhkjktlyfuflwnfk")
    public suspend
    fun brokeredMessageProperties(argument: suspend ServiceBusBrokeredMessagePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusBrokeredMessagePropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.brokeredMessageProperties = mapped
    }

    /**
     * @param value Gets or sets the custom message properties.
     */
    @JvmName("dwbqbbylmwibpfgh")
    public suspend fun customMessageProperties(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customMessageProperties = mapped
    }

    /**
     * @param values Gets or sets the custom message properties.
     */
    @JvmName("pvjfjmnkdxqtnxdj")
    public fun customMessageProperties(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customMessageProperties = mapped
    }

    /**
     * @param value Gets or sets the message.
     */
    @JvmName("thvnveoinkqwgown")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value Gets or sets the namespace.
     */
    @JvmName("tuoplqwklodnsukm")
    public suspend fun namespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespace = mapped
    }

    /**
     * @param value Gets or sets the topic path.
     */
    @JvmName("mldvbofrqhokctcd")
    public suspend fun topicPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.topicPath = mapped
    }

    /**
     * @param value Gets or sets the transport type.
     */
    @JvmName("bjdatjboillnbuda")
    public suspend fun transportType(`value`: ServiceBusTransportType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transportType = mapped
    }

    internal fun build(): ServiceBusTopicMessageArgs = ServiceBusTopicMessageArgs(
        authentication = authentication,
        brokeredMessageProperties = brokeredMessageProperties,
        customMessageProperties = customMessageProperties,
        message = message,
        namespace = namespace,
        topicPath = topicPath,
        transportType = transportType,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/scheduler/kotlin/inputs/ServiceBusTopicMessageArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.scheduler.kotlin.inputs

import com.pulumi.azurenative.scheduler.inputs.ServiceBusTopicMessageArgs.builder
import com.pulumi.azurenative.scheduler.kotlin.enums.ServiceBusTransportType
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 *
 * @property authentication Gets or sets the Service Bus authentication.
 * @property brokeredMessageProperties Gets or sets the brokered message properties.
 * @property customMessageProperties Gets or sets the custom message properties.
 * @property message Gets or sets the message.
 * @property namespace Gets or sets the namespace.
 * @property topicPath Gets or sets the topic path.
 * @property transportType Gets or sets the transport type.
 */
public data class ServiceBusTopicMessageArgs(
    public val authentication: Output<ServiceBusAuthenticationArgs>? = null,
    public val brokeredMessageProperties: Output<ServiceBusBrokeredMessagePropertiesArgs>? = null,
    public val customMessageProperties: Output<Map<String, String>>? = null,
    public val message: Output<String>? = null,
    public val namespace: Output<String>? = null,
    public val topicPath: Output<String>? = null,
    public val transportType: Output<ServiceBusTransportType>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.scheduler.inputs.ServiceBusTopicMessageArgs> {
    override fun toJava(): com.pulumi.azurenative.scheduler.inputs.ServiceBusTopicMessageArgs =
        com.pulumi.azurenative.scheduler.inputs.ServiceBusTopicMessageArgs.builder()
            .authentication(authentication?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .brokeredMessageProperties(
                brokeredMessageProperties?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .customMessageProperties(
                customMessageProperties?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .message(message?.applyValue({ args0 -> args0 }))
            .namespace(namespace?.applyValue({ args0 -> args0 }))
            .topicPath(topicPath?.applyValue({ args0 -> args0 }))
            .transportType(transportType?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [ServiceBusTopicMessageArgs].
 */
@PulumiTagMarker
public class ServiceBusTopicMessageArgsBuilder internal constructor() {
    private var authentication: Output<ServiceBusAuthenticationArgs>? = null

    private var brokeredMessageProperties: Output<ServiceBusBrokeredMessagePropertiesArgs>? = null

    private var customMessageProperties: Output<Map<String, String>>? = null

    private var message: Output<String>? = null

    private var namespace: Output<String>? = null

    private var topicPath: Output<String>? = null

    private var transportType: Output<ServiceBusTransportType>? = null

    /**
     * @param value Gets or sets the Service Bus authentication.
     */
    @JvmName("fmswcmsxmanyyath")
    public suspend fun authentication(`value`: Output<ServiceBusAuthenticationArgs>) {
        this.authentication = value
    }

    /**
     * @param value Gets or sets the brokered message properties.
     */
    @JvmName("qxiyrtmawwctwoxm")
    public suspend
    fun brokeredMessageProperties(`value`: Output<ServiceBusBrokeredMessagePropertiesArgs>) {
        this.brokeredMessageProperties = value
    }

    /**
     * @param value Gets or sets the custom message properties.
     */
    @JvmName("qufxktanywbfbhgt")
    public suspend fun customMessageProperties(`value`: Output<Map<String, String>>) {
        this.customMessageProperties = value
    }

    /**
     * @param value Gets or sets the message.
     */
    @JvmName("kqwpgiqxusjoryll")
    public suspend fun message(`value`: Output<String>) {
        this.message = value
    }

    /**
     * @param value Gets or sets the namespace.
     */
    @JvmName("qghialdqrnmkvouc")
    public suspend fun namespace(`value`: Output<String>) {
        this.namespace = value
    }

    /**
     * @param value Gets or sets the topic path.
     */
    @JvmName("kxnwfrwhbkiaqrds")
    public suspend fun topicPath(`value`: Output<String>) {
        this.topicPath = value
    }

    /**
     * @param value Gets or sets the transport type.
     */
    @JvmName("uvursnqoucsdnvoo")
    public suspend fun transportType(`value`: Output<ServiceBusTransportType>) {
        this.transportType = value
    }

    /**
     * @param value Gets or sets the Service Bus authentication.
     */
    @JvmName("aictpybjiqaimecb")
    public suspend fun authentication(`value`: ServiceBusAuthenticationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.authentication = mapped
    }

    /**
     * @param argument Gets or sets the Service Bus authentication.
     */
    @JvmName("lxtqqrtgkxqxbaja")
    public suspend
    fun authentication(argument: suspend ServiceBusAuthenticationArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusAuthenticationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.authentication = mapped
    }

    /**
     * @param value Gets or sets the brokered message properties.
     */
    @JvmName("mlhjekyrpdrvnqkf")
    public suspend fun brokeredMessageProperties(`value`: ServiceBusBrokeredMessagePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.brokeredMessageProperties = mapped
    }

    /**
     * @param argument Gets or sets the brokered message properties.
     */
    @JvmName("jwsodkpynvcrctnn")
    public suspend
    fun brokeredMessageProperties(argument: suspend ServiceBusBrokeredMessagePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = ServiceBusBrokeredMessagePropertiesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.brokeredMessageProperties = mapped
    }

    /**
     * @param value Gets or sets the custom message properties.
     */
    @JvmName("xwhqofwafbapednw")
    public suspend fun customMessageProperties(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.customMessageProperties = mapped
    }

    /**
     * @param values Gets or sets the custom message properties.
     */
    @JvmName("vpcrsbfkwblwrvrl")
    public fun customMessageProperties(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.customMessageProperties = mapped
    }

    /**
     * @param value Gets or sets the message.
     */
    @JvmName("xdmxxkuxjumyaqhm")
    public suspend fun message(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.message = mapped
    }

    /**
     * @param value Gets or sets the namespace.
     */
    @JvmName("adlpyxpmwsekpfyt")
    public suspend fun namespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespace = mapped
    }

    /**
     * @param value Gets or sets the topic path.
     */
    @JvmName("jjyxfnbwxdrsblpq")
    public suspend fun topicPath(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.topicPath = mapped
    }

    /**
     * @param value Gets or sets the transport type.
     */
    @JvmName("xpjsckcadvhsaytb")
    public suspend fun transportType(`value`: ServiceBusTransportType?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.transportType = mapped
    }

    internal fun build(): ServiceBusTopicMessageArgs = ServiceBusTopicMessageArgs(
        authentication = authentication,
        brokeredMessageProperties = brokeredMessageProperties,
        customMessageProperties = customMessageProperties,
        message = message,
        namespace = namespace,
        topicPath = topicPath,
        transportType = transportType,
    )
}
